@@ -5,12 +5,17 @@ from io import StringIO
 from unittest import mock
 
 from codicefiscale import __version__
-from codicefiscale.cli import run, run_with_args
+from codicefiscale.cli import _validate_from_args, run, run_with_args
 
 
-def assert_output(command, expected_output):
-    output = subprocess.check_output(command, shell=True).decode("utf-8").strip()
-    assert output == expected_output
+def assert_command_output(command, expected_output):
+    try:
+        output = subprocess.check_output(command, shell=True).decode("utf-8").strip()
+    except subprocess.CalledProcessError as error:
+        output = error.output.decode("utf-8").strip()
+    output = output.replace("\r\n", "\n").strip()
+    assert output == expected_output.replace("\r\n", "\n").strip()
+    return output
 
 
 def test_version():
@@ -25,7 +30,7 @@ def test_version():
 
 
 def test_version_from_command_line():
-    assert_output("python -m codicefiscale --version", __version__)
+    assert_command_output("python -m codicefiscale --version", __version__)
 
 
 def test_main_without_args():
@@ -37,7 +42,7 @@ def test_main_without_args():
 
 
 def test_main_without_args_from_command_line():
-    assert_output(
+    assert_command_output(
         "python -m codicefiscale",
         "For more info run: 'python -m codicefiscale --help'",
     )
@@ -59,14 +64,14 @@ def test_encode():
 
 
 def test_encode_from_command_line():
-    assert_output(
+    assert_command_output(
         (
             "python -m codicefiscale encode "
-            "--firstname 'Mario' "
-            "--lastname 'Rossi' "
-            "--gender 'M' "
-            "--birthdate '01/01/1990' "
-            "--birthplace 'Roma' "
+            "--firstname Mario "
+            "--lastname Rossi "
+            "--gender M "
+            "--birthdate 01/01/1990 "
+            "--birthplace Roma "
         ),
         "RSSMRA90A01H501W",
     )
@@ -168,10 +173,7 @@ def test_decode_without_omocodes():
 
 def test_decode_without_omocodes_from_command_line():
     cmd = "python -m codicefiscale decode 'RSSMRA90A01H501W'"
-    output = subprocess.check_output(cmd, shell=True).decode("UTF-8").strip()
-    assert (
-        output
-        == """
+    expected_output = """
 {
     "code": "RSSMRA90A01H501W",
     "gender": "M",
@@ -202,9 +204,8 @@ def test_decode_without_omocodes_from_command_line():
         "cin": "W"
     }
 }
-""".strip()
-    )
-
+"""
+    output = assert_command_output(cmd, expected_output)
     output_data = json.loads(output)
     assert output_data == {
         "code": "RSSMRA90A01H501W",
@@ -587,34 +588,30 @@ def test_decode_with_wrong_code():
 
 
 def test_validate():
-    with mock.patch("sys.stdout", new=StringIO()) as fake_output:
-        args = argparse.Namespace(
-            code="RSSMRA90A01H501W",
-            subcommand="validate",
-        )
-        run_with_args(args)
-        output = fake_output.getvalue().strip()
-        assert output == "✅"
+    args = argparse.Namespace(
+        code="RSSMRA90A01H501W",
+        subcommand="validate",
+    )
+    exit_code = _validate_from_args(args)
+    assert exit_code == 0
 
 
 def test_validate_from_command_line():
-    cmd = "python -m codicefiscale validate 'RSSMRA90A01H501W'"
-    output = subprocess.check_output(cmd, shell=True).decode("UTF-8").strip()
-    assert output == "✅"
+    cmd = "python -m codicefiscale validate RSSMRA90A01H501W"
+    result = subprocess.run(cmd, shell=True)
+    assert result.returncode == 0
 
 
 def test_validate_with_wrong_code():
-    with mock.patch("sys.stdout", new=StringIO()) as fake_output:
-        args = argparse.Namespace(
-            code="RSSMRA90A01H501X",
-            subcommand="validate",
-        )
-        run_with_args(args)
-        output = fake_output.getvalue().strip()
-        assert output == "❌"
+    args = argparse.Namespace(
+        code="RSSMRA90A01H501X",
+        subcommand="validate",
+    )
+    exit_code = _validate_from_args(args)
+    assert exit_code == 1
 
 
 def test_validate_with_wrong_code_from_command_line():
-    cmd = "python -m codicefiscale validate 'RSSMRA90A01H501X'"
-    output = subprocess.check_output(cmd, shell=True).decode("UTF-8").strip()
-    assert output == "❌"
+    cmd = "python -m codicefiscale validate RSSMRA90A01H501X"
+    result = subprocess.run(cmd, shell=True)
+    assert result.returncode == 1
